==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkDepthPeelingPass.java <==
// java wrapper for vtkDepthPeelingPass object
//

package vtk;
import vtk.*;

public class vtkDepthPeelingPass extends vtkOpenGLRenderPass
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ReleaseGraphicsResources_2(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_2(id0); }

  private native long GetTranslucentPass_3();
  public vtkRenderPass GetTranslucentPass() {
    long temp = GetTranslucentPass_3();

    if (temp == 0) return null;
    return (vtkRenderPass)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTranslucentPass_4(vtkRenderPass id0);
  public void SetTranslucentPass(vtkRenderPass id0)
    { SetTranslucentPass_4(id0); }

  private native void SetOcclusionRatio_5(double id0);
  public void SetOcclusionRatio(double id0)
    { SetOcclusionRatio_5(id0); }

  private native double GetOcclusionRatioMinValue_6();
  public double GetOcclusionRatioMinValue()
    { return GetOcclusionRatioMinValue_6(); }

  private native double GetOcclusionRatioMaxValue_7();
  public double GetOcclusionRatioMaxValue()
    { return GetOcclusionRatioMaxValue_7(); }

  private native double GetOcclusionRatio_8();
  public double GetOcclusionRatio()
    { return GetOcclusionRatio_8(); }

  private native void SetMaximumNumberOfPeels_9(int id0);
  public void SetMaximumNumberOfPeels(int id0)
    { SetMaximumNumberOfPeels_9(id0); }

  private native int GetMaximumNumberOfPeels_10();
  public int GetMaximumNumberOfPeels()
    { return GetMaximumNumberOfPeels_10(); }

  private native boolean ReplaceShaderValues_11(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4);
  public boolean ReplaceShaderValues(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4)
    { return ReplaceShaderValues_11(id0,id1,id2,id3,id4); }

  private native boolean SetShaderParameters_12(vtkShaderProgram id0,vtkAbstractMapper id1,vtkProp id2);
  public boolean SetShaderParameters(vtkShaderProgram id0,vtkAbstractMapper id1,vtkProp id2)
    { return SetShaderParameters_12(id0,id1,id2); }

  public vtkDepthPeelingPass() { super(); }

  public vtkDepthPeelingPass(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-armv7h.pkg.tar.xz: vtk/vtkDepthPeelingPass.java <==
// java wrapper for vtkDepthPeelingPass object
//

package vtk;
import vtk.*;

public class vtkDepthPeelingPass extends vtkOpenGLRenderPass
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ReleaseGraphicsResources_2(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_2(id0); }

  private native long GetTranslucentPass_3();
  public vtkRenderPass GetTranslucentPass() {
    long temp = GetTranslucentPass_3();

    if (temp == 0) return null;
    return (vtkRenderPass)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTranslucentPass_4(vtkRenderPass id0);
  public void SetTranslucentPass(vtkRenderPass id0)
    { SetTranslucentPass_4(id0); }

  private native void SetOcclusionRatio_5(double id0);
  public void SetOcclusionRatio(double id0)
    { SetOcclusionRatio_5(id0); }

  private native double GetOcclusionRatioMinValue_6();
  public double GetOcclusionRatioMinValue()
    { return GetOcclusionRatioMinValue_6(); }

  private native double GetOcclusionRatioMaxValue_7();
  public double GetOcclusionRatioMaxValue()
    { return GetOcclusionRatioMaxValue_7(); }

  private native double GetOcclusionRatio_8();
  public double GetOcclusionRatio()
    { return GetOcclusionRatio_8(); }

  private native void SetMaximumNumberOfPeels_9(int id0);
  public void SetMaximumNumberOfPeels(int id0)
    { SetMaximumNumberOfPeels_9(id0); }

  private native int GetMaximumNumberOfPeels_10();
  public int GetMaximumNumberOfPeels()
    { return GetMaximumNumberOfPeels_10(); }

  private native boolean PostReplaceShaderValues_11(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4);
  public boolean PostReplaceShaderValues(String id0,String id1,String id2,vtkAbstractMapper id3,vtkProp id4)
    { return PostReplaceShaderValues_11(id0,id1,id2,id3,id4); }

  private native void SetDepthFormat_12(int id0);
  public void SetDepthFormat(int id0)
    { SetDepthFormat_12(id0); }

  public vtkDepthPeelingPass() { super(); }

  public vtkDepthPeelingPass(long id) { super(id); }
  public native long   VTKInit();

}
